@@ -24,7 +24,9 @@ package MooX::Cmd::ChainedOptions;
 use strict;
 use warnings;
 
-our $VERSION = '0.03_02';
+our $VERSION = '0.01';
+
+use Carp;
 
 use Import::Into;
 use Moo::Role     ();
@@ -40,11 +42,8 @@ sub import {
     my $class  = shift;
     my $target = caller;
 
-    unless ( $target->DOES( 'MooX::Cmd::Role' ) ) {
-        require Carp;
-        Carp::croak( "$target must use MooX::Cmd prior to using ",
-            __PACKAGE__, "\n" );
-    }
+    croak( "$target must use MooX::Cmd prior to using ", __PACKAGE__, "\n" )
+      unless $target->DOES( 'MooX::Cmd::Role' );
 
     # don't do this twice
     return if $ROLE{$target};
@@ -63,15 +62,14 @@ sub import {
     $base ||= '';
     my $parent = first { $base eq $_->_build_command_base } keys %ROLE;
 
-    $ROLE{$target}
-      = $parent
-      ? MooX::Cmd::ChainedOptions::Role->build_variant( $parent,
-        $ROLE{$parent} )
-      : __PACKAGE__ . '::Base';
+    $ROLE{$target} =
+	$parent
+	     ? MooX::Cmd::ChainedOptions::Role->build_variant( $parent, $ROLE{$parent} )
+	     : __PACKAGE__ . '::Base';
 
     # need only apply role to commands & subcommands
     Moo::Role->apply_roles_to_package( $target, $ROLE{$target} )
-      if $parent;
+	if $parent;
 
     return;
 }
